@@ -24,15 +24,19 @@
 #include <config.h>
 #include "gnome-vfs-result.h"
 
-#include "gnome-vfs-i18n.h"
 #include <glib/gtypes.h>
+#include <glib/gi18n-lib.h>
 #include <errno.h>
+#ifndef G_OS_WIN32
 #include <netdb.h>
+#endif
 
+#ifndef G_OS_WIN32
 /* AIX #defines h_errno */
 #ifndef h_errno
 extern int h_errno;
 #endif
+#endif
 
 static char *status_strings[] = {
 	/* GNOME_VFS_OK */				N_("No error"),
@@ -83,20 +87,18 @@ static char *status_strings[] = {
 	/* GNOME_VFS_ERROR_LAUNCH */			N_("Error launching command"),
 	/* GNOME_VFS_ERROR_TIMEOUT */			N_("Timeout reached"),
 	/* GNOME_VFS_ERROR_NAMESERVER */                N_("Nameserver error"),
-	/* GNOME_VFS_ERROR_TIMEOUT */			N_("Timeout reached"),
  	/* GNOME_VFS_ERROR_LOCKED */			N_("The resource is locked"),
 	/* GNOME_VFS_ERROR_DEPRECATED_FUNCTION */       N_("Function call deprecated")
 };
 
-
 /**
- * gnome_vfs_result_from_errno_code
- * @errno_code: integer of the same type as the system "errno"
+ * gnome_vfs_result_from_errno_code:
+ * @errno_code: integer of the same type as the system "errno".
  *
- * Converts a system errno value to a GnomeVFSResult.
+ * Converts a system errno value to a #GnomeVFSResult.
  *
- * Return value: a GnomeVFSResult equivalent to @errno_code
- **/
+ * Return value: a #GnomeVFSResult equivalent to @errno_code.
+ */
 GnomeVFSResult
 gnome_vfs_result_from_errno_code (int errno_code)
 {
@@ -106,7 +108,9 @@ gnome_vfs_result_from_errno_code (int errno_code)
 	case EACCES:	   return GNOME_VFS_ERROR_ACCESS_DENIED;
 	case EBUSY:	   return GNOME_VFS_ERROR_DIRECTORY_BUSY;
 	case EBADF:	   return GNOME_VFS_ERROR_BAD_FILE;
+#ifdef ECONNREFUSED
 	case ECONNREFUSED: return GNOME_VFS_ERROR_SERVICE_NOT_AVAILABLE;
+#endif
 	case EEXIST:	   return GNOME_VFS_ERROR_FILE_EXISTS;
 	case EFAULT:	   return GNOME_VFS_ERROR_INTERNAL;
 	case EFBIG:	   return GNOME_VFS_ERROR_TOO_BIG;
@@ -114,10 +118,14 @@ gnome_vfs_result_from_errno_code (int errno_code)
 	case EINVAL:	   return GNOME_VFS_ERROR_BAD_PARAMETERS;
 	case EIO:	   return GNOME_VFS_ERROR_IO;
 	case EISDIR:	   return GNOME_VFS_ERROR_IS_DIRECTORY;
+#ifdef ELOOP
 	case ELOOP:	   return GNOME_VFS_ERROR_LOOP;
+#endif
 	case EMFILE:	   return GNOME_VFS_ERROR_TOO_MANY_OPEN_FILES;
 	case EMLINK:	   return GNOME_VFS_ERROR_TOO_MANY_LINKS;
+#ifdef ENETUNREACH
 	case ENETUNREACH:  return GNOME_VFS_ERROR_SERVICE_NOT_AVAILABLE;
+#endif
 	case ENFILE:	   return GNOME_VFS_ERROR_TOO_MANY_OPEN_FILES;
 #if ENOTEMPTY != EEXIST
 	case ENOTEMPTY:    return GNOME_VFS_ERROR_DIRECTORY_NOT_EMPTY;
@@ -128,7 +136,9 @@ gnome_vfs_result_from_errno_code (int errno_code)
 	case ENOTDIR:	   return GNOME_VFS_ERROR_NOT_A_DIRECTORY;
 	case EPERM:	   return GNOME_VFS_ERROR_NOT_PERMITTED;
 	case EROFS:	   return GNOME_VFS_ERROR_READ_ONLY_FILE_SYSTEM;
+#ifdef ETIMEDOUT
 	case ETIMEDOUT:    return GNOME_VFS_ERROR_TIMEOUT;
+#endif
 	case EXDEV:	   return GNOME_VFS_ERROR_NOT_SAME_FILE_SYSTEM;
 	
 		/* FIXME bugzilla.eazel.com 1191: To be completed.  */
@@ -139,25 +149,25 @@ gnome_vfs_result_from_errno_code (int errno_code)
 /**
  * gnome_vfs_result_from_errno:
  * 
- * Converts the system errno to a GnomeVFSResult.
+ * Converts the system errno to a #GnomeVFSResult.
  *
- * Return value: a GnomeVFSResult equivalent to the current system errno
- **/
+ * Return value: a #GnomeVFSResult equivalent to the current system errno.
+ */
 GnomeVFSResult
 gnome_vfs_result_from_errno (void)
 {
        return gnome_vfs_result_from_errno_code(errno);
 }
  
-
+#ifndef G_OS_WIN32
 /**
  * gnome_vfs_result_from_h_errno:
  * 
- * Converts the system "h_errno" to a GnomeVFSResult (h_errno represents errors
+ * Converts the system "h_errno" to a #GnomeVFSResult (h_errno represents errors
  * accessing and finding internet hosts)
  *
- * Return value: a GnomeVFSResult equivalent to the current system "h_errno"
- **/
+ * Return value: a #GnomeVFSResult equivalent to the current system "h_errno".
+ */
 GnomeVFSResult
 gnome_vfs_result_from_h_errno (void)
 {
@@ -166,17 +176,17 @@ gnome_vfs_result_from_h_errno (void)
 
 /**
  * gnome_vfs_result_from_h_errno_val:
- * @h_errno_code: A integer containing representing the same error codes
+ * @h_errno_code: an integer representing the same error code
  * as the system h_errno.
  * 
- * Converts the error code of @h_errno into a #GnomeVFSResult.
+ * Converts the error code @h_errno_code into a #GnomeVFSResult.
  * 
- * Return Value: The #GnomeVFSResult equivalent to the h_errno error code.
- **/
+ * Return Value: The #GnomeVFSResult equivalent to the @h_errno_code.
+ */
 GnomeVFSResult
 gnome_vfs_result_from_h_errno_val (int h_errno_code)
 {
-	switch (h_errno) {
+	switch (h_errno_code) {
 	case HOST_NOT_FOUND:	return GNOME_VFS_ERROR_HOST_NOT_FOUND;
 	case NO_ADDRESS:	return GNOME_VFS_ERROR_HOST_HAS_NO_ADDRESS;
 	case TRY_AGAIN:		return GNOME_VFS_ERROR_NAMESERVER;
@@ -185,16 +195,17 @@ gnome_vfs_result_from_h_errno_val (int h_errno_code)
 		return GNOME_VFS_ERROR_GENERIC;
 	}
 }
+#endif
 
 /**
  * gnome_vfs_result_to_string:
- * @result: the result to convert to a string
+ * @result: a #GnomeVFSResult to convert to a string.
  *
- * Returns a string representation of @result, useful for debugging
+ * Returns a string representing @result, useful for debugging
  * purposes, but probably not appropriate for passing to the user.
  *
- * Return value: a string representing @result
- **/
+ * Return value: a string representing @result.
+ */
 const char *
 gnome_vfs_result_to_string (GnomeVFSResult result)
 {
