@@ -1,6 +1,6 @@
 /* inotify-helper.h - GNOME VFS Monitor using inotify
 
-   Copyright (C) 2005 John McCutchan
+   Copyright (C) 2006 John McCutchan
 
    The Gnome Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License as
@@ -17,7 +17,7 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
 
-   Author: John McCutchan <ttb@tentacle.dhs.org>
+   Author: John McCutchan <john@johnmccutchan.com>
 */
 
 
@@ -27,16 +27,14 @@
 typedef struct {
 	GnomeVFSURI *uri;
 	GnomeVFSMonitorType type;
-	char *path;
-	char *dir;
+	char *pathname;
+	char *dirname;
 	char *filename;
 	guint32 extra_flags;
 	gboolean cancelled;
-	gboolean missing;
 } ih_sub_t;
 
 ih_sub_t	*ih_sub_new		(GnomeVFSURI *uri, GnomeVFSMonitorType);
 void		 ih_sub_free 	 	(ih_sub_t *sub);
-void		 ih_sub_setup		(ih_sub_t *sub);
 
 #endif /* __INOTIFY_SUB_H */
